from setuptools import setup

setup(name='byna_dist',
      version='0.1',
      author="Abubakar Abdusalam",
      author_email="abdusalam@bynalab.com",
      description='Gaussian distributions',
      packages=['byna_dist'],
      zip_safe=False)
